@@ -20,7 +20,7 @@ package MongoDB::Collection;
 # ABSTRACT: A MongoDB Collection
 
 use version;
-our $VERSION = 'v1.4.4';
+our $VERSION = 'v1.4.5';
 
 use MongoDB::Error;
 use MongoDB::IndexView;
@@ -1602,6 +1602,7 @@ my $legacy_update_args;
 sub update {
     my ( $self, $query, $object, $opts ) = @_;
     $opts ||= {};
+    $object ||= {};
 
     if ( exists $opts->{multiple} ) {
         if ( exists( $opts->{multi} ) && !!$opts->{multi} ne !!$opts->{multiple} ) {
@@ -1621,8 +1622,8 @@ sub update {
     );
     $fk = defined($fk) ? substr($fk,0,1) : '';
 
-    my $op_char = eval { $self->bson_codec->op_char } || '';
-    my $is_replace = $fk ne '$' && $fk ne $op_char;
+    my $op_char = eval { $self->bson_codec->op_char } || '$';
+    my $is_replace = $fk ne $op_char;
 
     my $op = MongoDB::Op::_Update->_new(
         filter => $query  || {},
@@ -1835,7 +1836,7 @@ MongoDB::Collection - A MongoDB Collection
 
 =head1 VERSION
 
-version v1.4.4
+version v1.4.5
 
 =head1 SYNOPSIS
 
